"""
Atmo Data Wrapper - Wrapper Python pour l'API Atmo Data
=====================================================

Ce package fournit un wrapper Python pour l'API Atmo Data (https://admindata.atmo-france.org),
permettant d'accéder facilement aux données de qualité de l'air et de pollution des 
Associations agréées de surveillance de la qualité de l'air (AASQA) françaises.

Modules principaux:
- client: Client principal pour l'API
- models: Classes pour les données typées
- constants: Constantes et configurations

Usage:
    from atmo_data_wrapper import AtmoDataClient
    
    client = AtmoDataClient()
    client.auto_login()
    indices = client.get_indices_atmo()
"""

__version__ = "1.0.0"
__author__ = "Atmo Data Wrapper Team"
__email__ = "contact@atmo-france.org"
__description__ = "Wrapper Python pour l'API Atmo Data"

# Import des classes principales pour faciliter l'usage
from .core.client import AtmoDataClient
from .core.models import (
    AtmoDataBase,
    IndiceAtmo, 
    EpisodePollution,
    EmissionData,
    IndicePollen,
    AtmoDataCollection,
    Coordinates
)
from .core.constants import (
    AASQA_CODES,
    INDICES_ATMO,
    INDICES_POLLENS,
    CODE_COLOR_QUALIF,
    CODE_POLLUANT,
    CODE_TAXON,
    SECTEURS_EMISSIONS,
    POLLUANTS,
    CODE_POLLUANT_EPISODES,
    TAXON_MAPPING,
    ATMO_LICENCE_COURTE,
    ATMO_LICENCE_LONGUE,
    ATMO_LICENCE_COMPLETE
)
from .core.utils import (
    get_aasqa_by_department,
    get_aasqa_info,
    get_aasqa_website,
    list_departments_by_aasqa,
    search_aasqa_by_name,
    get_departments_count,
    validate_department_coverage,
    get_aasqa_statistics,
    get_atmo_licence,
    print_atmo_licence
)
from .core.exceptions import AtmoDataException

__all__ = [
    # Client principal
    'AtmoDataClient',
    
    # Classes de données
    'AtmoDataBase',
    'IndiceAtmo',
    'EpisodePollution', 
    'EmissionData',
    'IndicePollen',
    'AtmoDataCollection',
    'Coordinates',
    
    # Constantes
    'AASQA_CODES',
    'INDICES_ATMO',
    'INDICES_POLLENS', 
    'CODE_COLOR_QUALIF',
    'CODE_POLLUANT',
    'CODE_TAXON',
    'SECTEURS_EMISSIONS',
    'POLLUANTS',
    'CODE_POLLUANT_EPISODES',
    'TAXON_MAPPING',
    'ATMO_LICENCE_COURTE',
    'ATMO_LICENCE_LONGUE',
    'ATMO_LICENCE_COMPLETE',
    
    # Fonctions utilitaires AASQA
    'get_aasqa_by_department',
    'get_aasqa_info',
    'get_aasqa_website',
    'list_departments_by_aasqa',
    'search_aasqa_by_name',
    'get_departments_count',
    'validate_department_coverage',
    'get_aasqa_statistics',
    'get_atmo_licence',
    'print_atmo_licence',
    
    # Exceptions
    'AtmoDataException'
]