"""
Core module for Atmo Data Wrapper
"""

from .client import AtmoDataClient
from .models import (
    AtmoDataBase,
    IndiceAtmo,
    EpisodePollution, 
    EmissionData,
    IndicePollen,
    AtmoDataCollection,
    Coordinates
)
from .constants import (
    AASQA_CODES,
    INDICES_ATMO,
    INDICES_POLLENS,
    CODE_COLOR_QUALIF,
    CODE_POLLUANT,
    CODE_TAXON,
    SECTEURS_EMISSIONS,
    POLLUANTS,
    CODE_POLLUANT_EPISODES,
    TAXON_MAPPING,
    ATMO_LICENCE_COURTE,
    ATMO_LICENCE_LONGUE,
    ATMO_LICENCE_COMPLETE
)
from .utils import (
    get_aasqa_by_department,
    get_aasqa_info,
    get_aasqa_website,
    list_departments_by_aasqa,
    search_aasqa_by_name,
    get_departments_count,
    validate_department_coverage,
    get_aasqa_statistics,
    get_atmo_licence,
    print_atmo_licence
)
from .exceptions import AtmoDataException

__all__ = [
    'AtmoDataClient',
    'AtmoDataBase',
    'IndiceAtmo',
    'EpisodePollution',
    'EmissionData', 
    'IndicePollen',
    'AtmoDataCollection',
    'Coordinates',
    'AASQA_CODES',
    'INDICES_ATMO',
    'INDICES_POLLENS',
    'CODE_COLOR_QUALIF',
    'CODE_POLLUANT',
    'CODE_TAXON',
    'SECTEURS_EMISSIONS',
    'POLLUANTS',
    'CODE_POLLUANT_EPISODES',
    'TAXON_MAPPING',
    'ATMO_LICENCE_COURTE',
    'ATMO_LICENCE_LONGUE',
    'ATMO_LICENCE_COMPLETE',
    'get_aasqa_by_department',
    'get_aasqa_info',
    'get_aasqa_website',
    'list_departments_by_aasqa',
    'search_aasqa_by_name',
    'get_departments_count',
    'validate_department_coverage',
    'get_aasqa_statistics',
    'get_atmo_licence',
    'print_atmo_licence',
    'AtmoDataException'
]