'''
Constantes pour le wrapper API Atmo Data
'''

# Formats de sortie supportés par l'API
FORMATS_VALIDES = ['geojson', 'csv']

# Codes AASQA (Associations Agréées de Surveillance de la Qualité de l'Air)
# Source : https://www.atmo-france.org/article/laasqa-de-votre-region
# Structure enrichie : région, organisme, départements, site web
AASQA_CODES = {
    '01': {
        'region': 'Guadeloupe',
        'organisme': 'Gwad\'Air',
        'departements': ['971'],
        'site_web': 'https://www.gwadair.gp',
        'description': 'Guadeloupe | Gwad\'Air'
    },
    '02': {
        'region': 'Martinique',
        'organisme': 'Madininair',
        'departements': ['972'],
        'site_web': 'https://www.madininair.fr',
        'description': 'Martinique | Madininair'
    },
    '03': {
        'region': 'Guyane',
        'organisme': 'Atmo Guyane',
        'departements': ['973'],
        'site_web': 'https://www.atmo-guyane.org',
        'description': 'Guyane | Atmo Guyane'
    },
    '04': {
        'region': 'La Réunion',
        'organisme': 'Atmo Réunion',
        'departements': ['974'],
        'site_web': 'https://www.atmo-reunion.net',
        'description': 'La Réunion | Atmo Réunion'
    },
    '06': {
        'region': 'Mayotte',
        'organisme': 'Hawa Mayotte',
        'departements': ['976'],
        'site_web': 'https://www.hawa-mayotte.org',
        'description': 'Mayotte | Hawa Mayotte'
    },
    '11': {
        'region': 'Île-de-France',
        'organisme': 'Airparif',
        'departements': ['75', '77', '78', '91', '92', '93', '94', '95'],
        'site_web': 'https://www.airparif.asso.fr',
        'description': 'Île-de-France | Airparif'
    },
    '24': {
        'region': 'Centre-Val de Loire',
        'organisme': 'Lig\'Air',
        'departements': ['18', '28', '36', '37', '41', '45'],
        'site_web': 'https://www.ligair.fr',
        'description': 'Centre-Val de Loire | Lig\'Air'
    },
    '27': {
        'region': 'Bourgogne-Franche-Comté',
        'organisme': 'Atmo Bourgogne-Franche-Comté',
        'departements': ['21', '25', '39', '58', '70', '71', '89', '90'],
        'site_web': 'https://www.atmo-bfc.org',
        'description': 'Bourgogne-Franche-Comté | Atmo Bourgogne-Franche-Comté'
    },
    '28': {
        'region': 'Normandie',
        'organisme': 'Atmo Normandie',
        'departements': ['14', '27', '50', '61', '76'],
        'site_web': 'https://www.atmo-normandie.fr',
        'description': 'Normandie | Atmo Normandie'
    },
    '32': {
        'region': 'Hauts-de-France',
        'organisme': 'Atmo Hauts-de-France',
        'departements': ['02', '59', '60', '62', '80'],
        'site_web': 'https://www.atmo-hdf.fr',
        'description': 'Hauts-de-France | Atmo Hauts-de-France'
    },
    '44': {
        'region': 'Grand Est',
        'organisme': 'ATMO Grand-Est',
        'departements': ['08', '10', '51', '52', '54', '55', '57', '67', '68', '88'],
        'site_web': 'https://www.atmo-grandest.eu',
        'description': 'Grand Est | ATMO Grand-Est'
    },
    '52': {
        'region': 'Pays de la Loire',
        'organisme': 'Air Pays de la Loire',
        'departements': ['44', '49', '53', '72', '85'],
        'site_web': 'https://www.airpl.org',
        'description': 'Pays de la Loire | Air Pays de la Loire'
    },
    '53': {
        'region': 'Bretagne',
        'organisme': 'Air Breizh',
        'departements': ['22', '29', '35', '56'],
        'site_web': 'https://www.airbreizh.asso.fr',
        'description': 'Bretagne | Air Breizh'
    },
    '75': {
        'region': 'Nouvelle-Aquitaine',
        'organisme': 'Atmo Nouvelle-Aquitaine',
        'departements': ['16', '17', '19', '23', '24', '33', '40', '47', '64', '79', '86', '87'],
        'site_web': 'https://www.atmo-nouvelleaquitaine.org',
        'description': 'Nouvelle-Aquitaine | Atmo Nouvelle-Aquitaine'
    },
    '76': {
        'region': 'Occitanie',
        'organisme': 'Atmo Occitanie',
        'departements': ['09', '11', '12', '30', '31', '32', '34', '46', '48', '65', '66', '81', '82'],
        'site_web': 'https://www.atmo-occitanie.org',
        'description': 'Occitanie | Atmo Occitanie'
    },
    '84': {
        'region': 'Auvergne-Rhône-Alpes',
        'organisme': 'Atmo Auvergne-Rhône-Alpes',
        'departements': ['01', '03', '07', '15', '26', '38', '42', '43', '63', '69', '73', '74'],
        'site_web': 'https://www.atmo-auvergnerhonealpes.fr',
        'description': 'Auvergne-Rhône-Alpes | Atmo Auvergne-Rhône-Alpes'
    },
    '93': {
        'region': 'Provence-Alpes-Côte d\'Azur',
        'organisme': 'AtmoSud',
        'departements': ['04', '05', '06', '13', '83', '84'],
        'site_web': 'https://www.atmosud.org',
        'description': 'Provence-Alpes-Côte d\'Azur | AtmoSud'
    },
    '94': {
        'region': 'Corse',
        'organisme': 'Qualitair',
        'departements': ['2A', '2B'],
        'site_web': 'https://www.qualitaircorse.org',
        'description': 'Corse | Qualitair'
    }
}


# Secteurs d'émission
SECTEURS_EMISSIONS = {
    '5': 'Agriculture',
    '6': 'Transport routier',
    '7': 'Autres transports',
    '34': 'Résidentiel - Tertiaire',
    '219': 'Industrie, branche énergie, déchets'
}

# Indices de qualité de l'air ATMO
# Source : https://www.atmo-france.org/article/lindice-atmo
# Source : Notice technique et d’information des données open data sur la qualité de l’air disponibles sur Atmo Data - Version 1er avril 2025
INDICES_ATMO = {
    0 : 'Absent',
    1 : 'Bon',
    2 : 'Moyen',
    3 : 'Dégradé',
    4 : 'Mauvais',
    5 : 'Très mauvais',
    6 : 'Extrêmement mauvais',
    7 : 'Événement'
}

# Indices polliniques
# Source : https://www.atmo-france.org/article/indice-pollen
# Source : Notice technique et d’information des données open data sur la qualité de l’air disponibles sur Atmo Data - Version 1er avril 2025
INDICES_POLLENS = {
    0 : 'Indisponible',
    1 : 'Très faible',
    2 : 'Faible',
    3 : 'Modéré',
    4 : 'Élevé',
    5 : 'Très élevé',
    6 : 'Extrêmement élevé'
}

# Couleur des qualificatifs des indices polluants et pollens :
# Source : https://www.atmo-france.org/article/lindice-atmo
# Source : https://www.atmo-france.org/article/indice-pollen
# Source : Notice technique et d’information des données open data sur la qualité de l’air disponibles sur Atmo Data - Version 1er avril 2025
# code_[polluant|pollen] | code couleur (R,V,B) | code couleur #hexa | emojis ronds | emojis carrées
CODE_COLOR_QUALIF = {
    0 : [(221,221,221), '#DDDDDD', "⚪", "⬜"],
    1 : [(80,240,230), '#50F0E6', "🔵", "🟦"],
    2 : [(80,204,170), '#50CCAA', "🟢", "🟩"],
    3 : [(240,230,65), '#F0E641', "🟡", "🟨"],
    4 : [(255,80,80), '#FF5050', "🔴", "🟥"],
    5 : [(150,0,50), '#960032', "🟤", "🟫"],
    6 : [(135,33,129), '#872181', "🟣", "🟪"],
    7 : [(136,136,136), '#888888', "⚫", "⬛"]
}
"""
Correspondances émojis/couleurs parfaites

- Niveau 0 : ⚪⬜ Gris clair #DDDDDD
- Niveau 1 : 🔵🟦 Bleu clair #50F0E6
- Niveau 2 : 🟢🟩 Vert #50CCAA
- Niveau 3 : 🟡🟨 Jaune #F0E641
- Niveau 4 : 🔴🟥 Rouge #FF5050
- Niveau 5 : 🟤🟫 Marron #960032
- Niveau 6 : 🟣🟪 Violet #872181
- Niveau 7 : ⚫⬛ Noir #888888

"""

# Types d'épisodes de pollution
TYPES_EPISODES = [
    'PAS DE DEPASSEMENT',
    'INFORMATION ET RECOMMANDATION', 
    'ALERTE SUR PERSISTANCE',
    'ALERTE'
]

# Échéances pour les épisodes de pollution (J-1, J0, J+1)
ECHEANCES_VALIDES = ['-1', '0', '1']

# Échelles d'agrégation pour les données d'émissions
ECHELLES_VALIDES = ['region', 'epci']

# URL par défaut de l'API
DEFAULT_API_URL = 'https://admindata.atmo-france.org'

# Timeout par défaut pour les requêtes (en secondes)
DEFAULT_TIMEOUT = 30

# Durée de validité du token JWT (en heures)
TOKEN_VALIDITY_HOURS = 24

# Formats de fichiers supportés pour la sauvegarde
SAVE_FORMATS = ['json', 'csv', 'geojson']

# Extensions de fichiers
FILE_EXTENSIONS = {
    'json': '.json',
    'csv': '.csv', 
    'geojson': '.geojson'
}

# Polluants réglementés pris en compte dans l'indice ATMO :
# Source : Notice technique et d’information des données open data sur la qualité de l’air disponibles sur Atmo Data - Version 1er avril 2025
POLLUANTS = ['NO2', 'SO2', 'PM10', 'PM2.5', 'O3']

CODE_POLLUANT = {
    'NO2' : 'dioxyde d’azote' ,
    'SO2' : 'dioxyde de soufre',
    'PM10' : 'particules fines inférieures à 10 micromètres',
    'PM2.5' : 'particules fines inférieures à 2.5 micromètres',
    'O3' : 'ozone'
}

# Mapping des codes polluants pour les épisodes de pollution
CODE_POLLUANT_EPISODES = {
    '1': 'NO2',
    '2': 'SO2', 
    '3': 'O3',
    '5': 'PM10',
    '6': 'PM2.5'
}

# Taxons (espèces) pris en compte dans l'indice pollen :
# Source : Notice technique et d’information des données open data sur la qualité de l’air disponibles sur Atmo Data - Version 1er avril 2025
CODE_TAXON = {
    'ambr' : 'Ambroisie',
    'arm' : 'Armoise',
    'aul' : 'Aulne',
    'boul' : 'Bouleau',
    'gram' : 'Graminées',
    'oliv' : 'Olivier',
}

# Mapping des variantes de noms de taxons vers les codes standards
TAXON_MAPPING = {
    'aulne': 'aul',
    'bouleau': 'boul', 
    'olivier': 'oliv',
    'graminées': 'gram',
    'graminee': 'gram',  # Variante sans accent
    'armoise': 'arm',
    'artemisi': 'arm',   # Variante latine de armoise
    'ambroisie': 'ambr'
}

# Mentions légales et licence Atmo France / AASQA
# Source : Notice technique et d’information des données open data sur la qualité de l’air disponibles sur Atmo Data - Version 1er avril 2025
ATMO_LICENCE_COURTE = "Atmo France / AASQA"

ATMO_LICENCE_LONGUE = "Atmo France et les Associations agréées de surveillance de la qualité de l'air"

ATMO_LICENCE_COMPLETE = """Données sous licence ODbL (Open Database License)
Source: Atmo France et les Associations agréées de surveillance de la qualité de l'air
URL: https://www.atmo-france.org/
API: https://admindata.atmo-france.org/

Chacun peut bénéficier gratuitement de ces données mises en open data sous licence ODbL, 
en indiquant la source "Atmo France et les Associations agréées de surveillance de la qualité de l'air" 
ou "Atmo France / AASQA" dans sa version courte."""

