"""
Setup configuration for Atmo Data Wrapper package
"""

from setuptools import setup, find_packages
import os

# Read the README file
with open("docs/README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

# Read version from package
def get_version():
    """Extract version from package __init__.py"""
    import sys
    sys.path.insert(0, os.path.dirname(__file__))
    from atmo_data_wrapper import __version__
    return __version__

setup(
    name="atmo-data-wrapper",
    version=get_version(),
    author="Mathdatech Team",
    author_email="mathdatech@mathdatech.fr",
    description="Wrapper Python pour l'API Atmo Data",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://git.mathdatech.fr/mathdatech/py_atmo_data_wrapper",
    project_urls={
        "Bug Tracker": "https://git.mathdatech.fr/mathdatech/py_atmo_data_wrapper/issues",
        "Documentation": "https://git.mathdatech.fr/mathdatech/py_atmo_data_wrapper/src/branch/main/docs/README.md",
        "API Documentation": "https://admindata.atmo-france.org/api/doc/v2",
        "Atmo France": "https://www.atmo-france.org"
    },
    packages=find_packages(),
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Intended Audience :: Science/Research",
        "Topic :: Scientific/Engineering :: Atmospheric Science",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Operating System :: OS Independent",
        "Natural Language :: French",
    ],
    python_requires=">=3.7",
    install_requires=[
        "requests>=2.25.0",
    ],
    extras_require={
        "dev": [
            "pytest>=6.0",
            "pytest-cov",
            "black",
            "flake8",
            "mypy",
        ],
        "docs": [
            "sphinx",
            "sphinx-rtd-theme",
        ],
    },
    entry_points={
        "console_scripts": [
            "atmo-data-test=atmo_data_wrapper.core.client:main",
        ],
    },
    include_package_data=True,
    package_data={
        "atmo_data_wrapper": [
            "*.json",
            "core/*.json",
        ],
    },
    keywords=[
        "atmo",
        "air quality",
        "pollution",
        "environment",
        "france",
        "aasqa",
        "api",
        "wrapper",
        "qualité air",
        "pollen",
        "emissions"
    ],
    zip_safe=False,
)
